==> haskell-data-textual-0.3.0.3-365-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-textual
version:              0.3.0.3
visibility:           public
id:                   data-textual-0.3.0.3-GIV3PzecCxa5znrrmI4Nv3
key:                  data-textual-0.3.0.3-GIV3PzecCxa5znrrmI4Nv3
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-textual
synopsis:             Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.

category:             Data, Text
abi:                  f9700635ed80051f4cb152a0a5f910d0
exposed:              True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-textual
hs-libraries:         HSdata-textual-0.3.0.3-GIV3PzecCxa5znrrmI4Nv3
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    parsers-0.12.12-3Y4v9RAdAf5L5ROf55wFur text-2.0.2
    text-latin1-0.3.1-8aotpe1rSb74uztVEgj4YN
    text-printer-0.5.0.2-Ec4RRPB9SJlGodiFWaqJF7

haddock-interfaces:
    /usr/share/doc/haskell-data-textual/html/data-textual.haddock

haddock-html:         /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.3-366-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-textual
version:              0.3.0.3
visibility:           public
id:                   data-textual-0.3.0.3-BNqduzEVpciJsUYGsmCjXt
key:                  data-textual-0.3.0.3-BNqduzEVpciJsUYGsmCjXt
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-textual
synopsis:             Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.

category:             Data, Text
abi:                  9621bad1a46e885a7a77107d118ee143
exposed:              True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-textual
hs-libraries:         HSdata-textual-0.3.0.3-BNqduzEVpciJsUYGsmCjXt
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    parsers-0.12.12-9BwrsDP3JpDKedhfp7gn2c text-2.0.2
    text-latin1-0.3.1-KDqZPOkssV9gwyrWK3JdF
    text-printer-0.5.0.2-GkMOA63uETjCAyYxlK8qRN

haddock-interfaces:
    /usr/share/doc/haskell-data-textual/html/data-textual.haddock

haddock-html:         /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
